==> monaco-vscode-bulk-edit-service-override-16.0.0.tgz: package/vscode/src/vs/workbench/contrib/bulkEdit/browser/preview/bulkEdit.contribution.js <==

import { __decorate, __param } from '@codingame/monaco-vscode-api/external/tslib/tslib.es6';
import { Registry } from '@codingame/monaco-vscode-api/vscode/vs/platform/registry/common/platform';
import { registerWorkbenchContribution2, WorkbenchPhase } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/contributions';
import { IBulkEditService } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/services/bulkEditService.service';
import { BulkEditPane } from './bulkEditPane.js';
import { ViewContainerLocation, Extensions } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/views';
import { IViewsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service';
import { FocusedViewContext } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/contextkeys';
import { localize, localize2 } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { ViewPaneContainer } from '@codingame/monaco-vscode-b1110435-a331-5549-ab1e-aa3d763c3a1f-common/vscode/vs/workbench/browser/parts/views/viewPaneContainer';
import { RawContextKey, ContextKeyExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { IContextKeyService } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey.service';
import { IEditorGroupsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorGroupsService.service';
import { KeybindingWeight } from '@codingame/monaco-vscode-api/vscode/vs/platform/keybinding/common/keybindingsRegistry';
import { KeyMod, KeyCode } from '@codingame/monaco-vscode-api/vscode/vs/base/common/keyCodes';
import { WorkbenchListFocusContextKey } from '@codingame/monaco-vscode-api/vscode/vs/platform/list/browser/listService';
import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import { registerAction2, Action2, MenuId } from '@codingame/monaco-vscode-api/vscode/vs/platform/actions/common/actions';
import { EditorResourceAccessor, SideBySideEditor } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor';
import { CancellationTokenSource } from '@codingame/monaco-vscode-api/vscode/vs/base/common/cancellation';
import { IDialogService } from '@codingame/monaco-vscode-api/vscode/vs/platform/dialogs/common/dialogs.service';
import Severity from '@codingame/monaco-vscode-api/vscode/vs/base/common/severity';
import { Codicon } from '@codingame/monaco-vscode-api/vscode/vs/base/common/codicons';
import { registerIcon } from '@codingame/monaco-vscode-api/vscode/vs/platform/theme/common/iconRegistry';
import { IPaneCompositePartService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';

var BulkEditPreviewContribution_1;
async function getBulkEditPane(viewsService) {
    const view = await viewsService.openView(BulkEditPane.ID, true);
    if (view instanceof BulkEditPane) {
        return view;
    }
    return undefined;
}
let UXState = class UXState {
    constructor(_paneCompositeService, _editorGroupsService) {
        this._paneCompositeService = _paneCompositeService;
        this._editorGroupsService = _editorGroupsService;
        this._activePanel = _paneCompositeService.getActivePaneComposite(ViewContainerLocation.Panel)?.getId();
    }
    async restore(panels, editors) {
        if (panels) {
            if (typeof this._activePanel === 'string') {
                await this._paneCompositeService.openPaneComposite(this._activePanel, ViewContainerLocation.Panel);
            }
            else {
                this._paneCompositeService.hideActivePaneComposite(ViewContainerLocation.Panel);
            }
        }
        if (editors) {
            for (const group of this._editorGroupsService.groups) {
                const previewEditors = [];
                for (const input of group.editors) {
                    const resource = EditorResourceAccessor.getCanonicalUri(input, { supportSideBySide: SideBySideEditor.PRIMARY });
                    if (resource?.scheme === BulkEditPane.Schema) {
                        previewEditors.push(input);
                    }
                }
                if (previewEditors.length) {
                    group.closeEditors(previewEditors, { preserveFocus: true });
                }
            }
        }
    }
};
UXState = ( __decorate([
    ( __param(0, IPaneCompositePartService)),
    ( __param(1, IEditorGroupsService))
], UXState));
class PreviewSession {
    constructor(uxState, cts = ( new CancellationTokenSource())) {
        this.uxState = uxState;
        this.cts = cts;
    }
}
let BulkEditPreviewContribution = class BulkEditPreviewContribution {
    static { BulkEditPreviewContribution_1 = this; }
    static { this.ID = 'workbench.contrib.bulkEditPreview'; }
    static { this.ctxEnabled = ( new RawContextKey('refactorPreview.enabled', false)); }
    constructor(_paneCompositeService, _viewsService, _editorGroupsService, _dialogService, bulkEditService, contextKeyService) {
        this._paneCompositeService = _paneCompositeService;
        this._viewsService = _viewsService;
        this._editorGroupsService = _editorGroupsService;
        this._dialogService = _dialogService;
        bulkEditService.setPreviewHandler(edits => this._previewEdit(edits));
        this._ctxEnabled = BulkEditPreviewContribution_1.ctxEnabled.bindTo(contextKeyService);
    }
    async _previewEdit(edits) {
        this._ctxEnabled.set(true);
        const uxState = this._activeSession?.uxState ?? ( new UXState(this._paneCompositeService, this._editorGroupsService));
        const view = await getBulkEditPane(this._viewsService);
        if (!view) {
            this._ctxEnabled.set(false);
            return edits;
        }
        if (view.hasInput()) {
            const { confirmed } = await this._dialogService.confirm({
                type: Severity.Info,
                message: ( localize(4219, "Another refactoring is being previewed.")),
                detail: ( localize(
                    4220,
                    "Press 'Continue' to discard the previous refactoring and continue with the current refactoring."
                )),
                primaryButton: ( localize(4221, "&&Continue"))
            });
            if (!confirmed) {
                return [];
            }
        }
        let session;
        if (this._activeSession) {
            await this._activeSession.uxState.restore(false, true);
            this._activeSession.cts.dispose(true);
            session = ( new PreviewSession(uxState));
        }
        else {
            session = ( new PreviewSession(uxState));
        }
        this._activeSession = session;
        try {
            return (await view.setInput(edits, session.cts.token)) ?? [];
        }
        finally {
            if (this._activeSession === session) {
                await this._activeSession.uxState.restore(true, true);
                this._activeSession.cts.dispose();
                this._ctxEnabled.set(false);
                this._activeSession = undefined;
            }
        }
    }
};
BulkEditPreviewContribution = BulkEditPreviewContribution_1 = ( __decorate([
    ( __param(0, IPaneCompositePartService)),
    ( __param(1, IViewsService)),
    ( __param(2, IEditorGroupsService)),
    ( __param(3, IDialogService)),
    ( __param(4, IBulkEditService)),
    ( __param(5, IContextKeyService))
], BulkEditPreviewContribution));
registerAction2(class ApplyAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.apply',
            title: ( localize2(4222, "Apply Refactoring")),
            category: ( localize2(4223, "Refactor Preview")),
            icon: Codicon.check,
            precondition: ( ContextKeyExpr.and(BulkEditPreviewContribution.ctxEnabled, BulkEditPane.ctxHasCheckedChanges)),
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 1
                }],
            keybinding: {
                weight: KeybindingWeight.EditorContrib - 10,
                when: ( ContextKeyExpr.and(BulkEditPreviewContribution.ctxEnabled, ( FocusedViewContext.isEqualTo(BulkEditPane.ID)))),
                primary: KeyMod.CtrlCmd + KeyCode.Enter,
            }
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.accept();
    }
});
registerAction2(class DiscardAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.discard',
            title: ( localize2(4224, "Discard Refactoring")),
            category: ( localize2(4223, "Refactor Preview")),
            icon: Codicon.clearAll,
            precondition: BulkEditPreviewContribution.ctxEnabled,
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 2
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.discard();
    }
});
registerAction2(class ToggleAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.toggleCheckedState',
            title: ( localize2(4225, "Toggle Change")),
            category: ( localize2(4223, "Refactor Preview")),
            precondition: BulkEditPreviewContribution.ctxEnabled,
            keybinding: {
                weight: KeybindingWeight.WorkbenchContrib,
                when: WorkbenchListFocusContextKey,
                primary: KeyCode.Space,
            },
            menu: {
                id: MenuId.BulkEditContext,
                group: 'navigation'
            }
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.toggleChecked();
    }
});
registerAction2(class GroupByFile extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.groupByFile',
            title: ( localize2(4226, "Group Changes By File")),
            category: ( localize2(4223, "Refactor Preview")),
            icon: Codicon.ungroupByRefType,
            precondition: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, ( BulkEditPane.ctxGroupByFile.negate()), BulkEditPreviewContribution.ctxEnabled)),
            menu: [{
                    id: MenuId.BulkEditTitle,
                    when: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, ( BulkEditPane.ctxGroupByFile.negate()))),
                    group: 'navigation',
                    order: 3,
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.groupByFile();
    }
});
registerAction2(class GroupByType extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.groupByType',
            title: ( localize2(4227, "Group Changes By Type")),
            category: ( localize2(4223, "Refactor Preview")),
            icon: Codicon.groupByRefType,
            precondition: ( ContextKeyExpr.and(
                BulkEditPane.ctxHasCategories,
                BulkEditPane.ctxGroupByFile,
                BulkEditPreviewContribution.ctxEnabled
            )),
            menu: [{
                    id: MenuId.BulkEditTitle,
                    when: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, BulkEditPane.ctxGroupByFile)),
                    group: 'navigation',
                    order: 3
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.groupByType();
    }
});
registerAction2(class ToggleGrouping extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.toggleGrouping',
            title: ( localize2(4227, "Group Changes By Type")),
            category: ( localize2(4223, "Refactor Preview")),
            icon: Codicon.listTree,
            toggled: ( BulkEditPane.ctxGroupByFile.negate()),
            precondition: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, BulkEditPreviewContribution.ctxEnabled)),
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 3
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.toggleGrouping();
    }
});
registerWorkbenchContribution2(BulkEditPreviewContribution.ID, BulkEditPreviewContribution, WorkbenchPhase.BlockRestore);
const refactorPreviewViewIcon = registerIcon('refactor-preview-view-icon', Codicon.lightbulb, ( localize(4228, 'View icon of the refactor preview view.')));
const container = ( Registry.as(Extensions.ViewContainersRegistry)).registerViewContainer({
    id: BulkEditPane.ID,
    title: ( localize2(4229, "Refactor Preview")),
    hideIfEmpty: true,
    ctorDescriptor: ( new SyncDescriptor(
        ViewPaneContainer,
        [BulkEditPane.ID, { mergeViewWithContainerWhenSingleView: true }]
    )),
    icon: refactorPreviewViewIcon,
    storageId: BulkEditPane.ID
}, ViewContainerLocation.Panel);
( Registry.as(Extensions.ViewsRegistry)).registerViews([{
        id: BulkEditPane.ID,
        name: ( localize2(4229, "Refactor Preview")),
        when: BulkEditPreviewContribution.ctxEnabled,
        ctorDescriptor: ( new SyncDescriptor(BulkEditPane)),
        containerIcon: refactorPreviewViewIcon,
    }], container);

==> monaco-vscode-bulk-edit-service-override-17.1.1.tgz: package/vscode/src/vs/workbench/contrib/bulkEdit/browser/preview/bulkEdit.contribution.js <==

import { __decorate, __param } from '@codingame/monaco-vscode-api/external/tslib/tslib.es6';
import { Registry } from '@codingame/monaco-vscode-api/vscode/vs/platform/registry/common/platform';
import { registerWorkbenchContribution2, WorkbenchPhase } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/contributions';
import { IBulkEditService } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/services/bulkEditService.service';
import { BulkEditPane } from './bulkEditPane.js';
import { ViewContainerLocation, Extensions } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/views';
import { IViewsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service';
import { FocusedViewContext } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/contextkeys';
import { localize, localize2 } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { ViewPaneContainer } from '@codingame/monaco-vscode-e67a0dae-5b2c-54e6-8d61-90102c78362d-common/vscode/vs/workbench/browser/parts/views/viewPaneContainer';
import { RawContextKey, ContextKeyExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { IContextKeyService } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey.service';
import { IEditorGroupsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorGroupsService.service';
import { KeybindingWeight } from '@codingame/monaco-vscode-api/vscode/vs/platform/keybinding/common/keybindingsRegistry';
import { KeyMod, KeyCode } from '@codingame/monaco-vscode-api/vscode/vs/base/common/keyCodes';
import { WorkbenchListFocusContextKey } from '@codingame/monaco-vscode-api/vscode/vs/platform/list/browser/listService';
import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import { registerAction2, Action2, MenuId } from '@codingame/monaco-vscode-api/vscode/vs/platform/actions/common/actions';
import { EditorResourceAccessor, SideBySideEditor } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor';
import { CancellationTokenSource } from '@codingame/monaco-vscode-api/vscode/vs/base/common/cancellation';
import { IDialogService } from '@codingame/monaco-vscode-api/vscode/vs/platform/dialogs/common/dialogs.service';
import Severity from '@codingame/monaco-vscode-api/vscode/vs/base/common/severity';
import { Codicon } from '@codingame/monaco-vscode-api/vscode/vs/base/common/codicons';
import { registerIcon } from '@codingame/monaco-vscode-api/vscode/vs/platform/theme/common/iconRegistry';
import { IPaneCompositePartService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';

var BulkEditPreviewContribution_1;
async function getBulkEditPane(viewsService) {
    const view = await viewsService.openView(BulkEditPane.ID, true);
    if (view instanceof BulkEditPane) {
        return view;
    }
    return undefined;
}
let UXState = class UXState {
    constructor(_paneCompositeService, _editorGroupsService) {
        this._paneCompositeService = _paneCompositeService;
        this._editorGroupsService = _editorGroupsService;
        this._activePanel = _paneCompositeService.getActivePaneComposite(ViewContainerLocation.Panel)?.getId();
    }
    async restore(panels, editors) {
        if (panels) {
            if (typeof this._activePanel === 'string') {
                await this._paneCompositeService.openPaneComposite(this._activePanel, ViewContainerLocation.Panel);
            }
            else {
                this._paneCompositeService.hideActivePaneComposite(ViewContainerLocation.Panel);
            }
        }
        if (editors) {
            for (const group of this._editorGroupsService.groups) {
                const previewEditors = [];
                for (const input of group.editors) {
                    const resource = EditorResourceAccessor.getCanonicalUri(input, { supportSideBySide: SideBySideEditor.PRIMARY });
                    if (resource?.scheme === BulkEditPane.Schema) {
                        previewEditors.push(input);
                    }
                }
                if (previewEditors.length) {
                    group.closeEditors(previewEditors, { preserveFocus: true });
                }
            }
        }
    }
};
UXState = ( __decorate([
    ( __param(0, IPaneCompositePartService)),
    ( __param(1, IEditorGroupsService))
], UXState));
class PreviewSession {
    constructor(uxState, cts = ( new CancellationTokenSource())) {
        this.uxState = uxState;
        this.cts = cts;
    }
}
let BulkEditPreviewContribution = class BulkEditPreviewContribution {
    static { BulkEditPreviewContribution_1 = this; }
    static { this.ID = 'workbench.contrib.bulkEditPreview'; }
    static { this.ctxEnabled = ( new RawContextKey('refactorPreview.enabled', false)); }
    constructor(_paneCompositeService, _viewsService, _editorGroupsService, _dialogService, bulkEditService, contextKeyService) {
        this._paneCompositeService = _paneCompositeService;
        this._viewsService = _viewsService;
        this._editorGroupsService = _editorGroupsService;
        this._dialogService = _dialogService;
        bulkEditService.setPreviewHandler(edits => this._previewEdit(edits));
        this._ctxEnabled = BulkEditPreviewContribution_1.ctxEnabled.bindTo(contextKeyService);
    }
    async _previewEdit(edits) {
        this._ctxEnabled.set(true);
        const uxState = this._activeSession?.uxState ?? ( new UXState(this._paneCompositeService, this._editorGroupsService));
        const view = await getBulkEditPane(this._viewsService);
        if (!view) {
            this._ctxEnabled.set(false);
            return edits;
        }
        if (view.hasInput()) {
            const { confirmed } = await this._dialogService.confirm({
                type: Severity.Info,
                message: ( localize(4248, "Another refactoring is being previewed.")),
                detail: ( localize(
                    4249,
                    "Press 'Continue' to discard the previous refactoring and continue with the current refactoring."
                )),
                primaryButton: ( localize(4250, "&&Continue"))
            });
            if (!confirmed) {
                return [];
            }
        }
        let session;
        if (this._activeSession) {
            await this._activeSession.uxState.restore(false, true);
            this._activeSession.cts.dispose(true);
            session = ( new PreviewSession(uxState));
        }
        else {
            session = ( new PreviewSession(uxState));
        }
        this._activeSession = session;
        try {
            return (await view.setInput(edits, session.cts.token)) ?? [];
        }
        finally {
            if (this._activeSession === session) {
                await this._activeSession.uxState.restore(true, true);
                this._activeSession.cts.dispose();
                this._ctxEnabled.set(false);
                this._activeSession = undefined;
            }
        }
    }
};
BulkEditPreviewContribution = BulkEditPreviewContribution_1 = ( __decorate([
    ( __param(0, IPaneCompositePartService)),
    ( __param(1, IViewsService)),
    ( __param(2, IEditorGroupsService)),
    ( __param(3, IDialogService)),
    ( __param(4, IBulkEditService)),
    ( __param(5, IContextKeyService))
], BulkEditPreviewContribution));
registerAction2(class ApplyAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.apply',
            title: ( localize2(4251, "Apply Refactoring")),
            category: ( localize2(4252, "Refactor Preview")),
            icon: Codicon.check,
            precondition: ( ContextKeyExpr.and(BulkEditPreviewContribution.ctxEnabled, BulkEditPane.ctxHasCheckedChanges)),
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 1
                }],
            keybinding: {
                weight: KeybindingWeight.EditorContrib - 10,
                when: ( ContextKeyExpr.and(BulkEditPreviewContribution.ctxEnabled, ( FocusedViewContext.isEqualTo(BulkEditPane.ID)))),
                primary: KeyMod.CtrlCmd + KeyCode.Enter,
            }
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.accept();
    }
});
registerAction2(class DiscardAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.discard',
            title: ( localize2(4253, "Discard Refactoring")),
            category: ( localize2(4252, "Refactor Preview")),
            icon: Codicon.clearAll,
            precondition: BulkEditPreviewContribution.ctxEnabled,
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 2
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.discard();
    }
});
registerAction2(class ToggleAction extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.toggleCheckedState',
            title: ( localize2(4254, "Toggle Change")),
            category: ( localize2(4252, "Refactor Preview")),
            precondition: BulkEditPreviewContribution.ctxEnabled,
            keybinding: {
                weight: KeybindingWeight.WorkbenchContrib,
                when: WorkbenchListFocusContextKey,
                primary: KeyCode.Space,
            },
            menu: {
                id: MenuId.BulkEditContext,
                group: 'navigation'
            }
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.toggleChecked();
    }
});
registerAction2(class GroupByFile extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.groupByFile',
            title: ( localize2(4255, "Group Changes By File")),
            category: ( localize2(4252, "Refactor Preview")),
            icon: Codicon.ungroupByRefType,
            precondition: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, ( BulkEditPane.ctxGroupByFile.negate()), BulkEditPreviewContribution.ctxEnabled)),
            menu: [{
                    id: MenuId.BulkEditTitle,
                    when: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, ( BulkEditPane.ctxGroupByFile.negate()))),
                    group: 'navigation',
                    order: 3,
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.groupByFile();
    }
});
registerAction2(class GroupByType extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.groupByType',
            title: ( localize2(4256, "Group Changes By Type")),
            category: ( localize2(4252, "Refactor Preview")),
            icon: Codicon.groupByRefType,
            precondition: ( ContextKeyExpr.and(
                BulkEditPane.ctxHasCategories,
                BulkEditPane.ctxGroupByFile,
                BulkEditPreviewContribution.ctxEnabled
            )),
            menu: [{
                    id: MenuId.BulkEditTitle,
                    when: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, BulkEditPane.ctxGroupByFile)),
                    group: 'navigation',
                    order: 3
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.groupByType();
    }
});
registerAction2(class ToggleGrouping extends Action2 {
    constructor() {
        super({
            id: 'refactorPreview.toggleGrouping',
            title: ( localize2(4256, "Group Changes By Type")),
            category: ( localize2(4252, "Refactor Preview")),
            icon: Codicon.listTree,
            toggled: ( BulkEditPane.ctxGroupByFile.negate()),
            precondition: ( ContextKeyExpr.and(BulkEditPane.ctxHasCategories, BulkEditPreviewContribution.ctxEnabled)),
            menu: [{
                    id: MenuId.BulkEditContext,
                    order: 3
                }]
        });
    }
    async run(accessor) {
        const viewsService = accessor.get(IViewsService);
        const view = await getBulkEditPane(viewsService);
        view?.toggleGrouping();
    }
});
registerWorkbenchContribution2(BulkEditPreviewContribution.ID, BulkEditPreviewContribution, WorkbenchPhase.BlockRestore);
const refactorPreviewViewIcon = registerIcon('refactor-preview-view-icon', Codicon.lightbulb, ( localize(4257, 'View icon of the refactor preview view.')));
const container = ( Registry.as(Extensions.ViewContainersRegistry)).registerViewContainer({
    id: BulkEditPane.ID,
    title: ( localize2(4258, "Refactor Preview")),
    hideIfEmpty: true,
    ctorDescriptor: ( new SyncDescriptor(
        ViewPaneContainer,
        [BulkEditPane.ID, { mergeViewWithContainerWhenSingleView: true }]
    )),
    icon: refactorPreviewViewIcon,
    storageId: BulkEditPane.ID
}, ViewContainerLocation.Panel);
( Registry.as(Extensions.ViewsRegistry)).registerViews([{
        id: BulkEditPane.ID,
        name: ( localize2(4258, "Refactor Preview")),
        when: BulkEditPreviewContribution.ctxEnabled,
        ctorDescriptor: ( new SyncDescriptor(BulkEditPane)),
        containerIcon: refactorPreviewViewIcon,
    }], container);
